function varargout = guizahl(varargin)
% GUIZAHL MATLAB code for guizahl.fig
%      GUIZAHL, by itself, creates a new GUIZAHL or raises the existing
%      singleton*.
%
%      H = GUIZAHL returns the handle to a new GUIZAHL or the handle to
%      the existing singleton*.
%
%      GUIZAHL('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in GUIZAHL.M with the given input arguments.
%
%      GUIZAHL('Property','Value',...) creates a new GUIZAHL or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before guizahl_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to guizahl_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help guizahl

% Last Modified by GUIDE v2.5 15-May-2017 10:14:01

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @guizahl_OpeningFcn, ...
                   'gui_OutputFcn',  @guizahl_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before guizahl is made visible.
function guizahl_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to guizahl (see VARARGIN)
    global zahl;
    zahl = randi(100);

% Choose default command line output for guizahl
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes guizahl wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = guizahl_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;



function edit1_Callback(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1 as text
%        str2double(get(hObject,'String')) returns contents of edit1 as a double


% --- Executes during object creation, after setting all properties.
function edit1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
    raten = str2double(get(handles.edit1,'String'));
    disp(raten);
    global zahl;
    if raten < 1 || raten > 100
      set(handles.text2,'String','Zahl ausserhalb des Bereichs.');
    end
    if raten == zahl
      set(handles.text2,'String','Richtig geraten!');
    elseif raten > zahl
      set(handles.text2,'String','Gesuchte Zahl ist kleiner.');
    else
      set(handles.text2,'String','Gesuchte Zahl ist groesser.');
    end;
    drawnow();